@@ -13,7 +13,9 @@ from .services.webhooks import update_shop_webhooks
 class ShopBase(models.Model):
 
     shopify_domain = models.CharField(max_length=50, default="")
-    shopify_token = models.CharField(max_length=150, default="")
+    shopify_token = models.CharField(
+        max_length=150, default="", blank=True, null=True
+    )
     access_scopes = models.CharField(max_length=50, default="")
 
     @cached_property
